# Capylang
### Capylang is a pretty simple language.
### Here is an example of using Capylang.
```python
from capylang import capy
capy.help() # Prints the functions down
capy.log("Hello, World!") # Prints Hello, World!
```
### That's pretty much it for a basic tutorial of Capylang.